*Navin Bapat & Menevis Cilizoglu
*Economic Coercion and the Problem of Sanctions-Proofing
*Conflict Management and Peace Science

*Replication File
clear 

*change working directory to the file the dataset (BapatCilizoglu_SanctionsProofing.dta) is in

cd " "

use "...BapatCilizoglu_SanctionsProofing.dta"


*Creating Variables

*coldwar
gen coldwar=1
replace coldwar=0 if year>1989

*cinc_ratio_ln
gen cinc_ratio=.
replace cinc_ratio=cap_1/cap_2
gen cinc_ratio_ln=ln(cinc_ratio)

*tradedep_t
gen tradedep_t=flowsum/totaltrade_t

tab tradedep_t if tradedep_t>0.9999

*there are 11 observations for which T's trade dependence is greater than 1, which cannot be true. This is indicative of a coding error in COW's Trade
*such that one country's total trade with a different country is coded greater than the national trade of the same country. Therefore, we create a new 
*variable that counts the variable as missing if tradedep_t is greater than 1. 

gen tradedep_t_edit=tradedep_t

replace tradedep_t_edit=. if tradedep_t>0.9999


*Democratic Target

gen t_dem_5=.
replace t_dem_5=1 if polity_t>5
replace t_dem_5=0 if polity_t<5
replace t_dem_5=0 if polity_t==5
replace t_dem_5=. if polity_t==.

*Temporal Controls

*splines
btscs threat year primarysender targetstate, g(iyeart) nspline(3)


*alternative temporal controls - Carter&Signorino 
gen iyeartt2 = iyeart^2
gen iyeartt3 = iyeart^3


*Table 2: Descriptive Statistics - Threat and Imposition

tab threat

tab imposition if threat==1

*Figure 2: Histogram - Credit Ratings of Targets of the U.S.

hist rating if threat==1


*Table 3: Heckman Selection Model: Sanction Threats and Impositions by the U.S.

heckprobit imposition rating tradedep_t_edit c.rating#c.tradedep_t_edit multisender t_dem_5 cinc_ratio_ln coldwar prev, select(threat= tradedep_t_edit s2un t_dem_5 cinc_ratio_ln prev coldwar iyeart iyeartt2 iyeartt3) vce (cluster targetstate)
*Table 4: Probit Models: Sanctions Threats and Impositions by the U.S.

*Model1: 
probit imposition rating tradedep_t_edit c.rating#c.tradedep_t_edit multisender t_dem_5 cinc_ratio_ln coldwar prev if threat==1, robust cluster(targetstate)

*Model2:

probit threat tradedep_t_edit s2un t_dem_5 cinc_ratio_ln prev coldwar iyeart iyeartt2 iyeartt3, robust cluster (targetstate)


*Figure 3: The Marginal Effect of Credit Rating on Sanctions Imposition

probit imposition rating tradedep_t_edit c.rating#c.tradedep_t_edit multisender t_dem_5 cinc_ratio_ln coldwar prev if threat==1, robust cluster(targetstate)

preserve

set seed 573936507

drawnorm SN_b1-SN_b9, n(10000) means(e(b)) cov(e(V)) clear


postutil clear
postfile mypost prob_hat0 lo0 hi0 prob_hat1 lo1 hi1 diff_hat diff_lo diff_hi using "/Users/menevis/Dropbox/Bapat-Cilizoglu/sim.dta", replace
            
noisily display "start"


local a=0
while `a' <= 1 { 

{

*set each variable to its mean. (ex: sum rating if threat==1) 

scalar h_rating= 41.73785
scalar h_tradedep_t_edit=.1930743
scalar h_t_dem_5= .452514
scalar h_multisender=.1666667
scalar h_cinc_ratio_ln = 4.165367
scalar h_coldwar= .8140704 
scalar h_prev=.6984925 
scalar h_constant=1

generate x_betahat0  = SN_b1*h_rating + SN_b2*`a' + SN_b3*h_rating*`a' + SN_b4*h_t_dem_5 + SN_b5*h_multisender +SN_b6*h_cinc_ratio_ln +SN_b7*h_coldwar + SN_b8*h_prev + SN_b9*h_constant
                            
generate x_betahat1  = SN_b1*(h_rating+25.13661) + SN_b2*`a' + SN_b3*(h_rating+25.13661)*(`a') + SN_b4*(h_t_dem_5) + SN_b5*(h_multisender) +SN_b6*(h_cinc_ratio_ln) +SN_b7*(h_coldwar)+ SN_b8*(h_prev) +SN_b9*h_constant
    	
	
    gen prob0 =normal(x_betahat0)
    gen prob1=normal(x_betahat1)
    gen diff=prob1-prob0
    
    egen probhat0 =mean(prob0)
    egen probhat1=mean(prob1)
    egen diffhat=mean(diff)
    
    tempname prob_hat0 lo0 hi0 prob_hat1 lo1 hi1 diff_hat diff_lo diff_hi

    _pctile prob0, p(5,95)
    scalar `lo0' = r(r1)
    scalar `hi0' = r(r2) 
    
    _pctile prob1, p(5,95)
    scalar `lo1'= r(r1)
    scalar `hi1'= r(r2) 
    
    _pctile diff, p(5,95)
    scalar `diff_lo'= r(r1)
    scalar `diff_hi'= r(r2) 
   
    scalar `prob_hat0'=probhat0
    scalar `prob_hat1'=probhat1
    scalar `diff_hat'=diffhat
    
    post mypost (`prob_hat0') (`lo0') (`hi0') (`prob_hat1') (`lo1') (`hi1') (`diff_hat') (`diff_lo') (`diff_hi')
   
    }

	drop x_betahat0 x_betahat1 prob0 prob1 diff probhat0 probhat1 diffhat
    
    local a=`a'+.01
   
    display "." _c
    
} 

display ""

postclose mypost

restore


*you may need to specify the folder the dta and the .do files are in.

merge using "/Users/menevis/Dropbox/Bapat-Cilizoglu/sim.dta"

gen yline=0

gen MV = (_n-1)/100

replace  MV=. if _n>101

graph twoway hist tradedep_t_edit if threat==1, percent color(gs14) yaxis(2) ///
        ||  line diff_hat MV, clwidth(medium) clcolor(blue) clcolor(black) ///
        ||  line diff_lo MV, clpattern(dash) clwidth(thin) clcolor(black) ///
        ||  line diff_hi MV, clpattern(dash) clwidth(thin) clcolor(black) ///
        ||  line yline MV,  clwidth(thin) clcolor(black) clpattern(solid) ///
        ||  , ///
            xlabel(0 .1 .2 .3 .4 .5 .6 .7 .8 .9, nogrid labsize(2)) ///
            ylabel(-.3 -.2 -.1 0 .1 .2 .3, axis(1) nogrid labsize(2)) ///
            ylabel(0 5 10 15 20 25 30, axis(2) nogrid labsize(2)) ///
            yscale(line alt) yscale(noline alt axis(2)) xscale(line) legend(off) ///
            yline(0, lcolor(black)) ///
            yline(.001 .003 .005 .007, lcolor(white)) ///
            xtitle("Trade Dependence", size(2.5)) ///
            ytitle("Marginal Effect of Credit Ratings", size(2.5)) ///
            ytitle("Percent of Observations" , axis(2) size(2.5)) ///
            xsca(titlegap(4)) ysca(titlegap(4)) ysca(axis(2) titlegap(4)) ///
            scheme(s2mono) graphregion(fcolor(white) ilcolor(white) lcolor(white))	


drop prob_hat0 lo0 hi0 prob_hat1 lo1 hi1 diff_hat diff_lo diff_hi _merge yline MV

*Figure 4: Predictive Effects of Credit Ratings on the Probability of Sanctions Imposition

probit imposition rating tradedep_t_edit c.rating#c.tradedep_t_edit multisender t_dem_5 cinc_ratio_ln coldwar prev if threat==1, robust cluster(targetstate)


quietly margins, at(tradedep_t_edit=(0(.1).4) rating=(67 42 17))
marginsplot


*Appendix B: Replication

*Histogram of Foreign Policy Similarity (s2un) and Relative CINC Scores-logged (cinc_ratio_ln)

hist s2un
graph save s2un

hist cinc_ratio_ln
graph save cinc_ratio_ln

graph combine s2un.gph cinc_ratio_ln.gph, cols(2)


* Table S1: Heckman Selection Model: Temporal Controls Included

heckprobit imposition rating tradedep_t_edit c.rating#c.tradedep_t_edit multisender t_dem_5 cinc_ratio_ln coldwar prev, select(threat= tradedep_t_edit s2un t_dem_5 cinc_ratio_ln prev coldwar iyeart iyeartt2 iyeartt3) vce (cluster targetstate)


* Table S2: Heckman Selection Model: Splines Included

heckprobit imposition rating tradedep_t_edit c.rating#c.tradedep_t_edit multisender t_dem_5 cinc_ratio_ln coldwar prev, select(threat= tradedep_t_edit s2un t_dem_5 cinc_ratio_ln prev coldwar iyeart _spline1 _spline2 _spline3) vce (cluster targetstate)


*Table S3: Heckman Selection Model: No Clustering

heckprobit imposition rating tradedep_t_edit c.rating#c.tradedep_t_edit multisender t_dem_5 cinc_ratio_ln coldwar prev, select(threat= tradedep_t_edit s2un t_dem_5 cinc_ratio_ln prev coldwar iyeart iyeartt2 iyeartt3)

*Table S4: Probit: Target Acquiescence

generate acquiesce_target=0
replace acquiesce_target=1 if finaloutcome==1
replace acquiesce_target=1 if finaloutcome==2
replace acquiesce_target=1 if finaloutcome==5
replace acquiesce_target=. if finaloutcome==.


probit acquiesce_target rating tradedep_t_edit s2un multisender prev cinc_ratio_ln coldwar asia europe africa americas mideast if threat==1, robust cluster(targetstate)


